==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/NXImage.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Common::NXImage::import{package Common::NXImage;no warnings;(my $source=
shift (@_));(my $destination=shift (@_));(my $tempDestination=($destination.
"\x2e\x70\x61\x72\x74"));if ((__import ($source,$tempDestination)<
(0x005d+ 9527-0x2594))){return ((0x000b+ 6226-0x185d));}if ((not (rename (
$tempDestination,$destination)))){Logger::warning (((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempDestination)."\x27\x20\x74\x6f\x20\x27").$destination).
"\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x20").$!)."\x2e"));if ((not (
unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x168d+ 3843-0x2590));}return ((0x0c8c+ 6759-0x26f2));}sub 
Common::NXImage::delete{package Common::NXImage;no warnings;(my $path=shift (@_)
);Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x44\x65\x6c\x65\x74\x65\x28"
.$path)."\x29"));(my $return=libnxhc::NXImageDelete ($path));Logger::debug ((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x44\x65\x6c\x65\x74\x65\x28"
.$path)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$return));if (($return<
(0x160f+ 1547-0x1c1a))){(my $errorNumber=libnxh::NXShellGetError ());(my $errorString
=libnxh::NXGetSystemErrorString ($errorNumber));Logger::warning (((((
"\x43\x6f\x75\x6c\x64\x6e\x27\x74\x20\x64\x65\x6c\x65\x74\x65\x20\x69\x6d\x61\x67\x65\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return ($return);}sub 
Common::NXImage::list{package Common::NXImage;no warnings;(my $path=shift (@_));
Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x4c\x69\x73\x74\x28"
.$path)."\x29"));(my $buffer=libnxhc::NXImageList ($path));Logger::debug ((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x4c\x69\x73\x74\x28"
.$path)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$buffer));(my (@files)=());if (
defined ($buffer)){(@files=split ( /\n/ ,$buffer,(0x0ee3+ 6009-0x265c)));}return
 (@files);}sub Common::NXImage::isoCreate{package Common::NXImage;no warnings;(my $output
=shift (@_));(my $input=shift (@_));(my $label=shift (@_));(my $joliet=shift (@_
));Logger::debug (((((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x73\x6f\x43\x72\x65\x61\x74\x65\x28"
.$output)."\x2c\x20").$input)."\x2c\x20").$label)."\x2c\x20").$joliet)."\x29"));
(my $return=libnxhc::NXIsoCreate ($output,$input,$label,$joliet));Logger::debug 
(((((((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x73\x6f\x43\x72\x65\x61\x74\x65\x28"
.$output)."\x2c\x20").$input)."\x2c\x20").$label)."\x2c\x20").$joliet).
"\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$return)."\x2e"));if (($return==
(0x001d+ 9622-0x25b3))){(my $errorNumber=NXPL::NXShellGetError ());(my $errorString
=NXPL::NXGetSystemErrorString ($errorNumber));Logger::error (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x72\x65\x61\x74\x65\x20\x49\x53\x4f\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return ($return);}sub 
Common::NXImage::replace{package Common::NXImage;no warnings;(my $source=shift (
@_));(my $destination=shift (@_));(my $tempDestination=($destination.
"\x2e\x70\x61\x72\x74"));if ((__import ($source,$tempDestination)<
(0x0137+ 3128-0x0d6f))){return ((0x01a3+ 4170-0x11ed));}if ((not (unlink (
$destination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$destination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));if ((
not (unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x060c+ 7702-0x2422));}if ((not (rename ($tempDestination,$destination)
))){Logger::warning (((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempDestination)."\x27\x20\x74\x6f\x20\x27").$destination).
"\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x20").$!)."\x2e"));if ((not (
unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x062a+ 7127-0x2201));}return ((0x0408+ 7428-0x210b));}sub 
Common::NXImage::__import{package Common::NXImage;no warnings;(my $source=shift 
(@_));(my $destination=shift (@_));Logger::debug (((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x49\x6d\x70\x6f\x72\x74\x28"
.$source)."\x2c\x20").$destination)."\x29"));(my $return=libnxhc::NXImageImport 
($source,$destination));Logger::debug ((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x49\x6d\x70\x6f\x72\x74\x28"
.$source)."\x2c\x20").$destination)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").
$return));if (($return<(0x0f2d+ 4846-0x221b))){(my $errorNumber=
libnxh::NXShellGetError ());(my $errorString=libnxh::NXGetSystemErrorString (
$errorNumber));Logger::warning (((((
"\x43\x6f\x75\x6c\x64\x6e\x27\x74\x20\x69\x6d\x70\x6f\x72\x74\x20\x69\x6d\x61\x67\x65\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));if (Common::NXFile::isExists (
$destination)){if ((not (unlink ($destination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$destination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}}}
return ($return);}package Common::NXImage;no warnings;"\x3f\x3f\x3f";

==> nomachine-8.0.168-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/NXImage.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Common::NXImage::import{package Common::NXImage;no warnings;(my $source=
shift (@_));(my $destination=shift (@_));(my $tempDestination=($destination.
"\x2e\x70\x61\x72\x74"));if ((__import ($source,$tempDestination)<
(0x161b+ 1944-0x1db3))){return ((0x0145+ 688-0x03f5));}if ((not (rename (
$tempDestination,$destination)))){Logger::warning (((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempDestination)."\x27\x20\x74\x6f\x20\x27").$destination).
"\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x20").$!)."\x2e"));if ((not (
unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x1e42+ 869-0x21a7));}return ((0x00f7+ 7986-0x2028));}sub 
Common::NXImage::delete{package Common::NXImage;no warnings;(my $path=shift (@_)
);Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x44\x65\x6c\x65\x74\x65\x28"
.$path)."\x29"));(my $return=libnxhc::NXImageDelete ($path));Logger::debug ((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x44\x65\x6c\x65\x74\x65\x28"
.$path)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$return));if (($return<
(0x06c3+ 5475-0x1c26))){(my $errorNumber=libnxh::NXShellGetError ());(my $errorString
=libnxh::NXGetSystemErrorString ($errorNumber));Logger::warning (((((
"\x43\x6f\x75\x6c\x64\x6e\x27\x74\x20\x64\x65\x6c\x65\x74\x65\x20\x69\x6d\x61\x67\x65\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return ($return);}sub 
Common::NXImage::list{package Common::NXImage;no warnings;(my $path=shift (@_));
Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x4c\x69\x73\x74\x28"
.$path)."\x29"));(my $buffer=libnxhc::NXImageList ($path));Logger::debug ((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x4c\x69\x73\x74\x28"
.$path)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$buffer));(my (@files)=());if (
defined ($buffer)){(@files=split ( /\n/ ,$buffer,(0x1b56+ 2461-0x24f3)));}return
 (@files);}sub Common::NXImage::isoCreate{package Common::NXImage;no warnings;(my $output
=shift (@_));(my $input=shift (@_));(my $label=shift (@_));(my $joliet=shift (@_
));Logger::debug (((((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x73\x6f\x43\x72\x65\x61\x74\x65\x28"
.$output)."\x2c\x20").$input)."\x2c\x20").$label)."\x2c\x20").$joliet)."\x29"));
(my $return=libnxhc::NXIsoCreate ($output,$input,$label,$joliet));Logger::debug 
(((((((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x73\x6f\x43\x72\x65\x61\x74\x65\x28"
.$output)."\x2c\x20").$input)."\x2c\x20").$label)."\x2c\x20").$joliet).
"\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$return)."\x2e"));if (($return==
(0x0f07+ 4128-0x1f27))){(my $errorNumber=NXPL::NXShellGetError ());(my $errorString
=NXPL::NXGetSystemErrorString ($errorNumber));Logger::error (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x72\x65\x61\x74\x65\x20\x49\x53\x4f\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return ($return);}sub 
Common::NXImage::replace{package Common::NXImage;no warnings;(my $source=shift (
@_));(my $destination=shift (@_));(my $tempDestination=($destination.
"\x2e\x70\x61\x72\x74"));if ((__import ($source,$tempDestination)<
(0x0fc9+ 1421-0x1556))){return ((0x0e83+ 3692-0x1cef));}if ((not (unlink (
$destination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$destination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));if ((
not (unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x0ee0+ 2279-0x17c7));}if ((not (rename ($tempDestination,$destination)
))){Logger::warning (((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempDestination)."\x27\x20\x74\x6f\x20\x27").$destination).
"\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x20").$!)."\x2e"));if ((not (
unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x1955+ 1578-0x1f7f));}return ((0x16db+ 1269-0x1bcf));}sub 
Common::NXImage::__import{package Common::NXImage;no warnings;(my $source=shift 
(@_));(my $destination=shift (@_));Logger::debug (((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x49\x6d\x70\x6f\x72\x74\x28"
.$source)."\x2c\x20").$destination)."\x29"));(my $return=libnxhc::NXImageImport 
($source,$destination));Logger::debug ((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x49\x6d\x70\x6f\x72\x74\x28"
.$source)."\x2c\x20").$destination)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").
$return));if (($return<(0x1eda+ 885-0x224f))){(my $errorNumber=
libnxh::NXShellGetError ());(my $errorString=libnxh::NXGetSystemErrorString (
$errorNumber));Logger::warning (((((
"\x43\x6f\x75\x6c\x64\x6e\x27\x74\x20\x69\x6d\x70\x6f\x72\x74\x20\x69\x6d\x61\x67\x65\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));if (Common::NXFile::isExists (
$destination)){if ((not (unlink ($destination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$destination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}}}
return ($return);}package Common::NXImage;no warnings;"\x3f\x3f\x3f";
